---
name: 🐛 Bug report
about: Create a report to make amends.
labels: [bug, triage]
title: ''
assignees: ''
---

<!-- ⚠️ If you do not respect this template, your issue will be closed -->
<!-- ⚠️ Make sure to browse the opened and closed issues -->

### System information
<!-- Please, provide some information about your system for debugging purposes. -->
- Device: <!-- (e.g. MacBook Pro (16-inch, 2019)) -->
- OS: <!-- (e.g. macOS Monterey version 12.3.1) -->
- Python version: <!-- (e.g. 3.8.9) -->
- Prototype version: <!-- (e.g. 1.0.0) -->


### What is the current behavior?
<!-- A clear and concise description of what the current behavior is. -->
<!-- If applicable, add screenshots to help explain your problem. -->


### What is the expected behavior?
<!-- A clear and concise description of what you expected to happen. -->


### Steps to reproduce the problem
<!-- Give some steps that show the bug. A minimal, working, code example with output is best. -->
<!-- If you are copying in code, please remember to enclose it in triple backticks, ``` [multiline code goes here] ```, so that it displays correctly. -->


### Additional context
<!-- Add any other context about the problem here if any. -->


### Suggestions
<!-- Not required, but if you have suggestions for how a contributor should fix this, or any problems we should be aware of, let us know. -->
